@@ -15,7 +15,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
-$VERSION = '1.0204';
+$VERSION = '1.0205';
 
 
 has permanent_path => (
@@ -648,7 +648,7 @@ This module allows you to summarize bodies of text into a scored hash of I<sente
 These scores reflect the weight (or precedence) of the relative text-fragments, i.e. how well they summarize or reflect the overall nature of the text.
 All of the sentences and phrase-fragments are drawn from within the existing text, and are NOT proceedurally generated.
 
-C< $summarizer->summarize_text > and C< $summarizer->summarize_file > each return a hash-ref containing three array-refs (C< $summarizer->summarize_all > returns a list of these hash-refs):
+C<< $summarizer->summarize_text >> and C<< $summarizer->summarize_file >> each return a hash-ref containing three array-refs (C<< $summarizer->summarize_all >> returns a list of these hash-refs):
 
 =over 2
 
@@ -661,7 +661,7 @@ a list of phrase fragments from the given article, scored as above
 =item B<    words>
 a list of all words in the article, scored by a three-factor system consisting of I<frequency of appearance>, I<population standard deviation of word clustering>, and I<use in selected phrase fragments>.
 
-The C< $summarizer->pretty_print > method prints a visually pleasing graph of the above three summary categories.
+The C<< $summarizer->pretty_print >> method prints a visually pleasing graph of the above three summary categories.
 
 =back
 
